@@ -142,7 +142,7 @@ var _ = Describe("Constructing nodes", func() {
 			Ω(node.ID).Should(BeNumerically(">", 0))
 			Ω(node.NodeType).Should(Equal(types.NodeTypeReportBeforeEach))
 
-			node.ReportEachBody(types.SpecReport{})
+			node.ReportEachBody(internal.NewSpecContext(nil), types.SpecReport{})
 			Ω(didRun).Should(BeTrue())
 
 			Ω(node.Body).Should(BeNil())
@@ -162,7 +162,7 @@ var _ = Describe("Constructing nodes", func() {
 			Ω(node.ID).Should(BeNumerically(">", 0))
 			Ω(node.NodeType).Should(Equal(types.NodeTypeReportAfterEach))
 
-			node.ReportEachBody(types.SpecReport{})
+			node.ReportEachBody(internal.NewSpecContext(nil), types.SpecReport{})
 			Ω(didRun).Should(BeTrue())
 
 			Ω(node.Body).Should(BeNil())
@@ -196,7 +196,7 @@ var _ = Describe("Constructing nodes", func() {
 				cl := types.NewCodeLocation(2)
 				cl2 := types.NewCustomCodeLocation("hi")
 				node, errors := internal.NewNode(dt, ntIt, "text", body, cl2, Offset(1))
-				//note that Offset overrides cl2
+				// note that Offset overrides cl2
 				Ω(node.CodeLocation.FileName).Should(Equal(cl.FileName))
 				ExpectAllWell(errors)
 			})
@@ -269,6 +269,7 @@ var _ = Describe("Constructing nodes", func() {
 		It("marks the node as Serial", func() {
 			node, errors := internal.NewNode(dt, ntIt, "text", body, Serial)
 			Ω(node.MarkedSerial).Should(BeTrue())
+			Ω(node.Labels).Should(Equal(Labels{"Serial"}))
 			ExpectAllWell(errors)
 		})
 		It("allows containers to be marked", func() {
@@ -444,9 +445,9 @@ var _ = Describe("Constructing nodes", func() {
 		})
 
 		It("validates labels", func() {
-			node, errors := internal.NewNode(dt, ntIt, "", body, cl, Label("A", "B&C", "C,D", "C,D ", "  "))
+			node, errors := internal.NewNode(dt, ntIt, "", body, cl, Label("A", "B&C", "C,D", "C,D ", "  ", ":Foo"))
 			Ω(node).Should(BeZero())
-			Ω(errors).Should(ConsistOf(types.GinkgoErrors.InvalidLabel("B&C", cl), types.GinkgoErrors.InvalidLabel("C,D", cl), types.GinkgoErrors.InvalidLabel("C,D ", cl), types.GinkgoErrors.InvalidEmptyLabel(cl)))
+			Ω(errors).Should(ConsistOf(types.GinkgoErrors.InvalidLabel("B&C", cl), types.GinkgoErrors.InvalidLabel("C,D", cl), types.GinkgoErrors.InvalidLabel("C,D ", cl), types.GinkgoErrors.InvalidEmptyLabel(cl), types.GinkgoErrors.InvalidLabel(":Foo", cl)))
 			Ω(dt.DidTrackDeprecations()).Should(BeFalse())
 		})
 	})
@@ -655,7 +656,7 @@ var _ = Describe("Constructing nodes", func() {
 })
 
 var _ = Describe("Node", func() {
-	//HERE - and all the fun edge cases
+	// HERE - and all the fun edge cases
 	Describe("The nodes that take more specific functions", func() {
 		var dt *types.DeprecationTracker
 		BeforeEach(func() {
@@ -861,7 +862,7 @@ var _ = Describe("Node", func() {
 				Ω(node.ID).Should(BeNumerically(">", 0))
 				Ω(node.NodeType).Should(Equal(types.NodeTypeReportAfterSuite))
 
-				node.ReportSuiteBody(types.Report{})
+				node.ReportSuiteBody(internal.NewSpecContext(nil), types.Report{})
 				Ω(didRun).Should(BeTrue())
 
 				Ω(node.CodeLocation).Should(Equal(cl))
@@ -885,7 +886,7 @@ var _ = Describe("Node", func() {
 				Ω(node.ID).Should(BeNumerically(">", 0))
 				Ω(node.NodeType).Should(Equal(types.NodeTypeReportBeforeSuite))
 
-				node.ReportSuiteBody(types.Report{})
+				node.ReportSuiteBody(internal.NewSpecContext(nil), types.Report{})
 				Ω(didRun).Should(BeTrue())
 
 				Ω(node.CodeLocation).Should(Equal(cl))
